@@ -1,11 +1,12 @@
 //! Result of the [`template`](crate::template!) macro.
 
 use std::any::Any;
+use std::borrow::Cow;
 use std::fmt;
 use std::rc::Rc;
 
 use crate::generic_node::GenericNode;
-use crate::rx::{create_memo, StateHandle};
+use crate::reactive::{create_memo, StateHandle};
 
 /// Internal type for [`Template`].
 #[derive(Clone)]
@@ -119,6 +120,12 @@ impl<G: GenericNode> Template<G> {
     }
 }
 
+impl<G: GenericNode> Default for Template<G> {
+    fn default() -> Self {
+        Self::empty()
+    }
+}
+
 impl<G: GenericNode> fmt::Debug for Template<G> {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         match &self.inner {
@@ -142,12 +149,51 @@ impl<G: GenericNode> IntoTemplate<G> for Template<G> {
     }
 }
 
-impl<T: fmt::Display + 'static, G: GenericNode> IntoTemplate<G> for T {
+impl<G: GenericNode> IntoTemplate<G> for &Template<G> {
     fn create(&self) -> Template<G> {
-        if let Some(str) = <dyn Any>::downcast_ref::<&str>(self) {
-            Template::new_node(G::text_node(str))
-        } else {
-            Template::new_node(G::text_node(&self.to_string()))
+        (*self).clone()
+    }
+}
+
+impl<T: fmt::Display + 'static, G: GenericNode> IntoTemplate<G> for T {
+    fn create(&self) -> Template<G> {
+        // Workaround for specialization.
+        // Inspecting the type is optimized away at compile time.
+
+        macro_rules! specialize_as_ref_to_str {
+            ($t: ty) => {{
+                if let Some(s) = <dyn Any>::downcast_ref::<$t>(self) {
+                    return Template::new_node(G::text_node(s.as_ref()));
+                }
+            }};
+            ($t: ty, $($rest: ty),*) => {{
+                specialize_as_ref_to_str!($t);
+                specialize_as_ref_to_str!($($rest),*);
+            }};
         }
+
+        macro_rules! specialize_num_with_lexical {
+            ($t: ty) => {{
+                if let Some(&n) = <dyn Any>::downcast_ref::<$t>(self) {
+                    return Template::new_node(G::text_node(&lexical::to_string(n)));
+                }
+            }};
+            ($t: ty, $($rest: ty),*) => {{
+                specialize_num_with_lexical!($t);
+                specialize_num_with_lexical!($($rest),*);
+            }};
+        }
+
+        // Strings and string slices.
+        specialize_as_ref_to_str!(&str, String, Rc<str>, Rc<String>, Cow<'_, str>);
+
+        // Numbers use lexical.
+        specialize_num_with_lexical!(
+            i8, i16, i32, i64, i128, isize, u8, u16, u32, u64, u128, usize, f32, f64
+        );
+
+        // Generic slow-path.
+        let t = self.to_string();
+        Template::new_node(G::text_node(&t))
     }
 }
